<?php

@( (bool)FALSE === strpos( $_SERVER['REQUEST_URI'], basename( __FILE__ ) ) ) OR exit( '!! ACCESS DENIED !!' );
error_reporting( _E_VALUE );


/* vim: set expandtab tabstop=4 shiftwidth=4: */
// +----------------------------------------------------------------------+
// | myPHPNuke Version 188_8 RC2                                          |
// +----------------------------------------------------------------------+
// | License: GNU/GPL - http://www.gnu.org/copyleft/gpl.html              |
// +----------------------------------------------------------------------+
// | Support: http://myphpnuke.com/                                       |
// +----------------------------------------------------------------------+
// | Author: myPHPNuke Dev Team                                           |
// +----------------------------------------------------------------------+
// | Copyright: © 2001-2004 myPHPNuke Dev Team                            |
// +----------------------------------------------------------------------+
// $Id: main.php,v 1.4.2.5 2004/08/15 12:58:22 kirilt Exp $


checkAccess( 'blocks', array( 'left' ) );

include ("admin/qotd/qotd.$phpEx");
global $hlpfile;
$hlpfile = getHelpFile("quote.htm","myphpnuke");

if (!isset($op))
{
    $op = null;
}

switch($op)
{
   case "QotdAdd":
      // change the fields here for the quotes table
      QotdAdd($qquote, $qauthor);
      break;

   case "QotdSave":
      QotdSave($qqid,$qquote,$qauthor,$page);
      break;

   case "QotdDeleteOk":
      QotdDeleteOk($qid,$page);
      break;

   case "QotdDisplay":
      include("header.$phpEx");
      admin_menu($hlpfile);
      echo "<br>";
      QotdDisplay($page);
      echo "<br>";
      include("footer.$phpEx");
      break;

   case "QotdDelete":
      include("header.$phpEx");
      admin_menu($hlpfile);
      echo "<br>";
      QotdDelete($qid,$page);
      echo "<br>";
      include("footer.$phpEx");
      break;

   case "QotdEdit":
      include("header.$phpEx");
      admin_menu($hlpfile);
      echo "<br>";
      QotdEdit($qid,$page);
      echo "<br>";
      include("footer.$phpEx");
      break;

   default:
      include("header.$phpEx");
      admin_menu($hlpfile);
      echo "<br>";
      QotdAdmin();
      echo "<br>";
      include("footer.$phpEx");
      break;
}
?>
